import tape from 'tape';
import {
  is,
  fromJS,
  Iterable,
  List,
  Map,
  OrderedMap
} from 'immutable';

import {
  deepDelete,
  deepDeleteChildren
} from '../delete';

const nestedMaps = fromJS({
  a: {
    b: "B"
  },
  f: "F"
});

const childLists = fromJS({
  name: "root",
  children: [
    {
      name: "child 1",
      children: [
        {name: "grandchild 1"},
        {name: "grandchild 2"}
      ]
    }
  ]
});

tape('deepDelete', test => {
    test.plan(2);

    test.ok(is(
    	nestedMaps.update(deepDelete(['a','b'])),
      fromJS({
		    a: {
		    },
		    f: "F"
		  })
    ), 'using no childPath works like deleteIn');

    test.ok(is(
      childLists.update(deepDelete([0,0], ['children'])),
      fromJS({
	    name: "root",
	    children: [
	      {
	        name: "child 1",
	        children: [
	          {name: "grandchild 2"}
	        ]
	      }
	    ]
	  })
    ), 'using childPath works correctly');
});

tape('deepDeleteChildren', test => {
    test.plan(4);

    test.ok(is(
    	nestedMaps.update(deepDeleteChildren(['a'])),
    	fromJS({
		    a: {
		    },
		    f: "F"
		  })
    ), 'using no childPath clears children');

    test.ok(is(
      nestedMaps.update(deepDeleteChildren(['f'])),
      nestedMaps
    ), 'using no childPath on a childless node does nothing');

    test.ok(is(
      childLists.update(deepDeleteChildren([0], ['children'])),
      fromJS({
	      name: "root",
	      children: [
	        {
	          name: "child 1",
	          children: [
	          ]
	        }
	      ]
	    })
    ), 'using childPath works correctly');

    test.ok(is(
      childLists.update(deepDeleteChildren([0,1], ['children'])),
      fromJS({
        name: "root",
        children: [
          {
            name: "child 1",
            children: [
              {name: "grandchild 1"},
              {name: "grandchild 2"}
            ]
          }
        ]
      })
    ), 'using childPath on a childless node does nothing');
});