import tape from 'tape';
import {
  is,
  fromJS,
  Iterable,
  List,
  Map,
  OrderedMap
} from 'immutable';

import {
  deepFilter
} from '../filter';

import {
  isLeaf
} from '../utils';

const nestedMaps = fromJS({
  a: {
    b: "B",
    c: "C",
    d: "DD",
    e: {
      e: "E",
      f: "FF",
      g: "G"
    }
  },
  h: "H"
});

const childLists = fromJS({
  name: "root",
  cool: true,
  children: [
    {
      name: "child 1",
      cool: true,
      children: [
        {name: "grandchild 1", cool: true},
        {name: "grandchild 2"}
      ]
    },
    {
      name: "child 2",
      children: [
        {name: "grandchild 3", cool: true},
        {name: "grandchild 4"}
      ]
    },
    {name: "child 3", cool: true}
  ]
});

tape('deepFilter', test => {
  test.plan(2);
  test.ok(is(
    childLists.update(deepFilter(item => item.get('cool'), ['children'])),
    fromJS({
      name: "root",
      cool: true,
      children: [
        {
          name: "child 1",
          cool: true,
          children: [
            {name: "grandchild 1", cool: true}
          ]
        },
        {name: "child 3", cool: true}
      ]
    })
  ), 'deepFilter filters using a childPath');

  test.ok(is(
    nestedMaps.update(deepFilter(item => {
      // remove items that are strings and that are more than 1 character long
      return !(typeof item == "string" && item.length > 1);
    })),
    fromJS({
      a: {
        b: "B",
        c: "C",
        e: {
          e: "E",
          g: "G"
        }
      },
      h: "H"
    })
  ), 'deepFilter filters without using a childPath (kind of pointless)');
});