import tape from 'tape';
import {
  is,
  fromJS,
  Iterable,
  List,
  Map,
  OrderedMap
} from 'immutable';

import {
  deepPick
} from '../pick';

import {
  isLeaf
} from '../utils';

const nestedMaps = fromJS({
  a: {
    b: "B",
    c: "C",
    d: {
      e: "E"
    }
  },
  f: "F"
});

const childLists = fromJS({
  name: "root",
  children: [
    {
      name: "child 1",
      children: [
        {name: "grandchild 1"},
        {name: "grandchild 2"}
      ]
    },
    {
      name: "child 2",
      children: []
    },
    {name: "child 3"}
  ]
});

tape('deepPick', test => {
    test.plan(4);

    test.ok(is(
    	childLists.update(deepPick([0,1], ['children'])),
    	fromJS({
		  name: "root",
		  children: [
		    {
		      name: "child 1",
		      children: [
		        {name: "grandchild 2"}
		      ]
		    }
		  ]
		})
    ), 'deepPick picks out only values in a nodePath using a childPath');

    test.ok(is(
    	childLists.update(deepPick([0], ['children'])),
    	fromJS({
		  name: "root",
		  children: [
		    {
		      name: "child 1",
		      children: []
		    }
		  ]
		})
    ), 'deepPick picks out only values in a nodePath using a childPath, without children of the last item in the nodePath');

    test.ok(is(
    	nestedMaps.update(deepPick(['a','d','e'])),
    	fromJS({
		  a: {
		    d: {
		      e: "E"
		    }
		  }
		})
    ), 'deepPick picks out only values in a nodePath without using a childPath');

    test.ok(is(
    	nestedMaps.update(deepPick(['a','d'])),
    	fromJS({
		  a: {
		    d: {
		    }
		  }
		})
    ), 'deepPick picks out only values in a nodePath without using a childPath, without children of the last item in the nodePath');
});